@@ -1,6 +1,9 @@
 import hashlib
-from json import JSONDecodeError
 from datetime import datetime, timezone
+from json import JSONDecodeError
+
+import cloudscraper
+from requests import RequestException
 
 from pixivapi.common import HEADERS, format_bool, parse_qs, require_auth
 from pixivapi.enums import (
@@ -19,7 +22,6 @@ from pixivapi.models import (
     Novel,
     User,
 )
-from requests import RequestException, Session
 
 AUTH_URL = 'https://oauth.secure.pixiv.net/auth/token'
 BASE_URL = 'https://app-api.pixiv.net'
@@ -60,7 +62,7 @@ class Client:
         self.access_token = None
         self.refresh_token = None
 
-        self.session = Session()
+        self.session = cloudscraper.create_scraper()
         self.session.headers.update(HEADERS)
         if self.language:
             self.session.headers.update({'Accept-Language': self.language})
@@ -373,7 +375,7 @@ class Client:
         response = self._request_json(
             method='get',
             url=f'{BASE_URL}/v2/illust/follow',
-            params={'restrict': visibility.value},
+            params={'restrict': visibility.value, 'offset': offset},
         )
 
         return {
@@ -612,22 +614,24 @@ class Client:
         }
 
     @require_auth
-    def add_bookmark(self, illustration_id, visibility=Visibility.PUBLIC):
+    def add_bookmark(self, illustration_id, visibility=Visibility.PUBLIC, tags=None):
         """
         Bookmark an illustration.
 
         :param int illustration_id: The ID of the illustration.
         :param Visibility visibility: The visibility of the bookmark.
+        :param list tags: The bookmark tags of the illustration.
 
         :raises requests.RequestException: If the request fails.
         """
-        # TODO: Figure out correct way to serialize tags.
+        if tags:
+            tags = ' '.join(tags)
         self.session.post(
             url=f'{BASE_URL}/v2/illust/bookmark/add',
             data={
                 'illust_id': illustration_id,
                 'restrict': visibility.value,
-                'tags': None,
+                'tags[]': tags,
             },
         )
 
